==> redquicklib-1.289.0.tgz: package/lib/userservice.js <==
import createService from './service';
import { parameters } from './endPoints';
import * as Globals from './globals';

const endpoints = {
    GetPermissions: 'api/user/get/permissions',
    RequestUploadEndpoint: 'api/user/request/upload/endpoint',
    CompleteUpload: 'api/user/complete/upload',
    GetResources: 'api/user/get/resources',
    DeleteResources: 'api/user/delete/resource',
    EmitMessage: 'api/user/emit/message',
    GetNotifications: 'api/user/get/notifications',
    GetWebRTC: 'api/user/get/web/rtc',
}

var formatjson = '?format=json';
var userservice = createService(Globals.DEFAULT_URL);

export default {
    getWebRTC: async () => {
        return userservice.get(endpoints.GetWebRTC);
    },
    getPermissions: async () => {
        return userservice.get(parameters(endpoints.GetPermissions));
    },
    requestUploadEndpoint: async (ops) => {
        var body = JSON.stringify(ops);
        return userservice.post(endpoints.RequestUploadEndpoint, body);
    },
    completeUpload: async (ops) => {
        var body = JSON.stringify(ops);
        return userservice.post(endpoints.CompleteUpload, body);
    },
    getResources: async req => {
        var body = JSON.stringify(req);

        return userservice.post(endpoints.GetResources, body);
    },
    getNotifications: async (signature) => {
        return userservice.get(parameters(endpoints.GetNotifications, signature));
    },
    deleteResource: async id => {
        return userservice.delete(parameters(endpoints.DeleteResources, id));
    },
    emitMessage: async (to, body) => {
        return userservice.post(parameters(endpoints.EmitMessage, to), body);
    }
}

==> redquicklib-1.500.0.tgz: package/lib/userservice.js <==
import * as RED from './service';
import { parameters } from './endPoints';
import * as Globals from './globals';

const endpoints = {
    GetPermissions: 'api/user/get/permissions',
    RequestUploadEndpoint: 'api/user/request/upload/endpoint',
    CompleteUpload: 'api/user/complete/upload',
    GetResources: 'api/user/get/resources',
    DeleteResources: 'api/user/delete/resource',
    EmitMessage: 'api/user/emit/message',
    GetNotifications: 'api/user/get/notifications',
    GetWebRTC: 'api/user/get/web/rtc',
}

var formatjson = '?format=json';
var userservice = RED.createRedService(Globals.DEFAULT_URL);

export default {
    getWebRTC: async () => {
        return userservice.get(endpoints.GetWebRTC);
    },
    getPermissions: async () => {
        return userservice.get(parameters(endpoints.GetPermissions));
    },
    requestUploadEndpoint: async (ops) => {
        var body = JSON.stringify(ops);
        return userservice.post(endpoints.RequestUploadEndpoint, body);
    },
    completeUpload: async (ops) => {
        var body = JSON.stringify(ops);
        return userservice.post(endpoints.CompleteUpload, body);
    },
    getResources: async req => {
        var body = JSON.stringify(req);

        return userservice.post(endpoints.GetResources, body);
    },
    getNotifications: async (signature) => {
        return userservice.get(parameters(endpoints.GetNotifications, signature));
    },
    deleteResource: async id => {
        return userservice.delete(parameters(endpoints.DeleteResources, id));
    },
    emitMessage: async (to, body) => {
        return userservice.post(parameters(endpoints.EmitMessage, to), body);
    }
}
